@@ -1,8 +1,8 @@
 import os
 from pathlib import Path
-from typing import Callable, Union, List
+from typing import Callable, Union, List, Optional
 
-from git import Repo
+from git import Repo, repo, Head
 
 from flexlate.constants import DEFAULT_MERGED_BRANCH_NAME, DEFAULT_TEMPLATE_BRANCH_NAME
 from flexlate.ext_git import (
@@ -11,6 +11,8 @@ from flexlate.ext_git import (
     fast_forward_branch_without_checkout,
     checked_out_template_branch,
     merge_branch_into_current,
+    abort_merge,
+    reset_branch_to_commit_without_checkout,
 )
 from flexlate.path_ops import make_func_that_creates_cwd_and_out_root_before_running
 from flexlate.transactions.transaction import (
@@ -25,7 +27,10 @@ def modify_files_via_branches_and_temp_repo(
     commit_message: str,
     out_root: Path,
     merged_branch_name: str = DEFAULT_MERGED_BRANCH_NAME,
+    base_merged_branch_name: str = DEFAULT_MERGED_BRANCH_NAME,
     template_branch_name: str = DEFAULT_TEMPLATE_BRANCH_NAME,
+    base_template_branch_name: str = DEFAULT_TEMPLATE_BRANCH_NAME,
+    remote: str = "origin",
 ):
     cwd = os.getcwd()
     current_branch = repo.active_branch
@@ -36,7 +41,10 @@ def modify_files_via_branches_and_temp_repo(
 
     # Update the template only branch with the new template
     with temp_repo_that_pushes_to_branch(  # type: ignore
-        repo, branch_name=template_branch_name
+        repo,
+        branch_name=template_branch_name,
+        base_branch_name=base_template_branch_name,
+        remote=remote,
     ) as temp_repo:
         make_dirs_add_operation(Path(temp_repo.working_dir))  # type: ignore
         stage_and_commit_all(temp_repo, commit_message)
@@ -44,7 +52,9 @@ def modify_files_via_branches_and_temp_repo(
     # Bring the change into the merged branch
     # Update with changes from the main repo
     fast_forward_branch_without_checkout(repo, merged_branch_name, current_branch.name)
-    with checked_out_template_branch(repo, branch_name=merged_branch_name):
+    with checked_out_template_branch(
+        repo, branch_name=merged_branch_name, base_branch_name=base_merged_branch_name
+    ):
         # Update with the new template
         merge_branch_into_current(repo, template_branch_name)
 
@@ -67,11 +77,16 @@ def undo_transaction_in_flexlate_branches(
     repo: Repo,
     transaction: FlexlateTransaction,
     merged_branch_name: str = DEFAULT_MERGED_BRANCH_NAME,
+    base_merged_branch_name: str = DEFAULT_MERGED_BRANCH_NAME,
     template_branch_name: str = DEFAULT_TEMPLATE_BRANCH_NAME,
+    base_template_branch_name: str = DEFAULT_TEMPLATE_BRANCH_NAME,
 ):
     # Reset the template only branch to the appropriate commit
     with temp_repo_that_pushes_to_branch(  # type: ignore
-        repo, branch_name=template_branch_name, force_push=True
+        repo,
+        branch_name=template_branch_name,
+        base_branch_name=base_template_branch_name,
+        force_push=True,
     ) as temp_repo:
         reset_last_transaction(
             temp_repo, transaction, merged_branch_name, template_branch_name
@@ -79,8 +94,38 @@ def undo_transaction_in_flexlate_branches(
 
     # Reset the merged template branch to the appropriate commit
     with temp_repo_that_pushes_to_branch(  # type: ignore
-        repo, branch_name=merged_branch_name, force_push=True
+        repo,
+        branch_name=merged_branch_name,
+        base_branch_name=base_merged_branch_name,
+        force_push=True,
     ) as temp_repo:
         reset_last_transaction(
             temp_repo, transaction, merged_branch_name, template_branch_name
         )
+
+
+def abort_merge_and_reset_flexlate_branches(
+    repo: Repo,
+    current_branch: Head,
+    merged_branch_sha: Optional[str] = None,
+    template_branch_sha: Optional[str] = None,
+    merged_branch_name: str = DEFAULT_MERGED_BRANCH_NAME,
+    template_branch_name: str = DEFAULT_TEMPLATE_BRANCH_NAME,
+):
+    abort_merge(repo)
+    current_branch.checkout()
+    reset_branch_to_commit_without_checkout(repo, merged_branch_name, merged_branch_sha)
+    reset_branch_to_commit_without_checkout(
+        repo, template_branch_name, template_branch_sha
+    )
+
+
+def get_flexlate_branch_name(repo: Repo, base_branch_name: str) -> str:
+    current_branch = repo.active_branch.name
+    return get_flexlate_branch_name_for_feature_branch(current_branch, base_branch_name)
+
+
+def get_flexlate_branch_name_for_feature_branch(
+    feature_branch: str, base_branch_name: str
+) -> str:
+    return f"{base_branch_name}-{feature_branch}"
